'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var core = require('@ts-rest/core');
var vueQuery = require('@tanstack/vue-query');

const queryFn = (route, clientArgs, argsMapper) => {
    return async (queryFnContext) => {
        const args = typeof argsMapper === 'function'
            ? argsMapper(queryFnContext)
            : argsMapper;
        const fetchApiArgs = core.evaluateFetchApiArgs(route, clientArgs, args);
        const result = await core.fetchApi({
            ...fetchApiArgs,
            fetchOptions: {
                ...((queryFnContext === null || queryFnContext === void 0 ? void 0 : queryFnContext.signal) && { signal: queryFnContext.signal }),
                ...fetchApiArgs.fetchOptions,
            },
        });
        if (!String(result.status).startsWith('2')) {
            throw result;
        }
        return result;
    };
};

const getRouteUseQuery = (route, clientArgs) => {
    return (queryKey, args, options) => {
        const dataFn = queryFn(route, clientArgs, args);
        return vueQuery.useQuery({ queryKey, queryFn: dataFn, ...options });
    };
};

const getRouteUseInfiniteQuery = (route, clientArgs) => (queryKey, argsMapper, options) => {
    const dataFn = async (context) => {
        const resultingQueryArgs = argsMapper(context);
        const innerDataFn = queryFn(route, clientArgs, resultingQueryArgs);
        return innerDataFn(undefined);
    };
    return vueQuery.useInfiniteQuery({
        queryKey,
        queryFn: dataFn,
        ...options,
    });
};

const getRouteUseMutation = (route, clientArgs) => (options) => {
    const mutationFunction = async (args) => {
        const dataFn = queryFn(route, clientArgs, args);
        return dataFn(undefined);
    };
    return vueQuery.useMutation({
        mutationFn: mutationFunction,
        ...options,
    });
};

const initQueryClient = (router, args) => Object.fromEntries(Object.entries(router).map(([key, subRouter]) => core.isAppRoute(subRouter)
    ? [
        key,
        {
            query: core.getRouteQuery(subRouter, args),
            mutation: core.getRouteQuery(subRouter, args),
            useQuery: getRouteUseQuery(subRouter, args),
            useInfiniteQuery: getRouteUseInfiniteQuery(subRouter, args),
            useMutation: getRouteUseMutation(subRouter, args),
        },
    ]
    : [key, initQueryClient(subRouter, args)]));

exports.initQueryClient = initQueryClient;
